@@ -4,17 +4,13 @@ use warnings;
 use strict;
 
 use base qw/Class::Accessor::Fast/;
-__PACKAGE__->mk_accessors qw/
-    input_filters
-    output_filters
-    filters
-    /;
+__PACKAGE__->mk_accessors(qw/ input_filters output_filters filters /);
 
 =head1 NAME
 
 Jifty::DBI::HasFilters - abstract class for objects that has filters
 
-=head1 SYNOPSYS
+=head1 SYNOPSIS
 
   my $record = Jifty::DBI::Record->new(...);
   $record->input_filters( 'Jifty::DBI::Filter::Truncate',
